@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-auto-tangle" "0.7.0"
+(define-package "org-auto-tangle" "20251230.1416"
   "Automatically and Asynchronously tangles org files on save."
   '((emacs "24.1")
     (async "1.9.3"))
